@@ -1,16 +1,17 @@
 ##=============================================================================
-##' @title Perform the CATATIS method on different blocks of binary data from a CATA experiment
+##' @title Perform the CATATIS method on different blocks from a CATA experiment
 ##'
 ##' @usage
-##' catatis(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weights=TRUE)
+##' catatis(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weights=TRUE,
+##'  Test_weights=FALSE, nperm=100)
 ##'
 ##' @description
-##' CATATIS method on binary blocks. Additional outputs are also computed
+##' CATATIS method. Additional outputs are also computed. Non-binary data are accepted and weights can be tested.
 ##'
 ##'
 ##' @param Data data frame or matrix where the blocks of binary variables are merged horizontally. If you have a different format, see \code{\link{change_cata_format}}
 ##'
-##' @param nblo  numerical. Number of blocks (subjects).
+##' @param nblo integer. Number of blocks (subjects).
 ##'
 ##' @param NameBlocks string vector. Name of each block (subject). Length must be equal to the number of blocks. If NULL, the names are S1,...Sm. Default: NULL
 ##'
@@ -20,12 +21,16 @@
 ##'
 ##' @param Graph_weights logical. Should the barplot of the weights be plotted? Default: TRUE
 ##'
+##' @param Test_weights logical. Should the the weights be tested? Default: FALSE
+##'
+##' @param nperm integer. Number of permutation for the weight tests. Default: 100
 ##'
 ##' @return a list with:
 ##'         \itemize{
 ##'          \item S: the S matrix: a matrix with the similarity coefficient among the subjects
 ##'          \item compromise: a matrix which is the compromise of the subjects (akin to a weighted average)
 ##'          \item weights: the weights associated with the subjects to build the compromise
+##'          \item weights_tests: the weights tests results
 ##'          \item lambda:  the first eigenvalue of the S matrix
 ##'          \item overall error: the error for the CATATIS criterion
 ##'          \item error_by_sub: the error by subject (CATATIS criterion)
@@ -46,29 +51,39 @@
 ##'
 ##' @references
 ##' Llobell, F., Cariou, V., Vigneau, E., Labenne, A., & Qannari, E. M. (2019). A new approach for the analysis of data and the clustering of subjects in a CATA experiment. Food Quality and Preference, 72, 31-39.
-##'
+##' Bonnet, L., Ferney, T., Riedel, T., Qannari, E.M., Llobell, F. (September 14, 2022) .Using CATA for sensory profiling: assessment of the panel performance. Eurosense, Turku, Finland.
 ##'
 ##' @importFrom FactoMineR CA
 ##' @importFrom stats var
 ##' @importFrom stats quantile
+##' @importFrom stats t.test
+##' @importFrom stats median
 ##'
 ##'
 ##' @examples
 ##' data(straw)
 ##' res.cat=catatis(straw, nblo=114)
 ##' summary(res.cat)
+##' plot(res.cat)
 ##'
-##' @seealso   \code{\link{plot.catatis}}, \code{\link{summary.catatis}}, \code{\link{cluscata}}, \code{\link{change_cata_format}}
+##' #Vertical format with sessions
+##' data("PB_tuna")
+##' chang=change_cata_format2(PB_tuna, nprod= 6, nattr= 27, nsub = 12, nsess= 3)
+##' res.cat2=catatis(Data= chang$Datafinal, nblo = 12, NameBlocks =  chang$NameSub, Test_weights=TRUE)
+##'
+##' #Vertical format without sessions
+##' Data=PB_tuna[1:66,2:30]
+##' chang2=change_cata_format2(Data, nprod= 6, nattr= 27, nsub = 11, nsess= 1)
+##' res.cat3=catatis(Data= chang2$Datafinal, nblo = 11, NameBlocks =  chang2$NameSub)
+##'
+##' @seealso   \code{\link{plot.catatis}}, \code{\link{summary.catatis}}, \code{\link{cluscata}}, \code{\link{change_cata_format}}, \code{\link{change_cata_format2}}
 ##'
 ##' @export
 
 ##=============================================================================
 
 
-
-
-catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weights=TRUE){
-
+catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weights=TRUE, Test_weights=FALSE, nperm=100){
 
   #initialisation
   n=nrow(Data)
@@ -106,11 +121,6 @@ catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weig
     }
   }
 
-  #parapet for binary Data
-  if ((sum(Data==0)+sum(Data==1))!=(dim(Data)[1]*dim(Data)[2]))
-  {
-    stop("only binary Data is accepted (0 or 1)")
-  }
   #parapet for number of objects
   if(n<3)
   {
@@ -142,10 +152,12 @@ catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weig
 
   Xj=array(0,dim=c(n,nvar,nblo))  # array with all subjects matrices
   muk=NULL
+  nb1=NULL
   for(j in 1:nblo)
   {
     Aj=as.matrix(X[,J==j])
-    normXj=sqrt(sum(Aj==1))
+    nb1[j]=sum(Aj)
+    normXj=sqrt(sum(diag(tcrossprod(Aj,Aj))))
     muk[j]=normXj
     if(normXj==0)
     {
@@ -258,8 +270,46 @@ catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weig
     print(plot.CA(e,title=paste("CATATIS")))
   }
 
+  #weight tests
+  if (Test_weights==TRUE)
+  {
+    Weightsperm=NULL
+    nperm=100
+    tirage=sample(1:nblo, nperm, replace = TRUE)
+    den=sum(diag(t(C)%*%C))
+    for (i in 1:nperm)
+    {
+      Mat=Xj[,,tirage[i]]
+      tirage2=sample(1:n)
+      Matpermut=as.matrix(Mat[tirage2,])
+      Weightsperm=c(Weightsperm, sum(diag(t(C)%*%Matpermut))/den)
+    }
+    valcrit=t.test(Weightsperm, alternative = "l")$conf.int[2]
 
-  names(u)=names(s)=rownames(S)=colnames(S)= names(dw)=names(muk)=names(facteurech)=NameBlocks
+    Matrep=matrix(0, nrow=nblo, ncol=4)
+    Matrep=as.data.frame(Matrep)
+    Matrep[,1]=round(u,3)
+    Matrep[,2]=rep(round(valcrit,3), nblo)
+    for (l in 1:nblo)
+    {
+      if (u[l]>valcrit)
+      {
+        Matrep[l,3]=round(u[l]-valcrit, 3)
+        Matrep[l,4]="Yes"
+      }else{
+        Matrep[l,3]=NA
+        Matrep[l,4]="No"
+      }
+    }
+    colnames(Matrep)=c("Weights", "Critical value", "Dist with CV", "Signif")
+    rownames(Matrep)= NameBlocks
+  }else{
+    Matrep=NULL
+  }
+
+
+
+  names(u)=names(s)=rownames(S)=colnames(S)= names(dw)=names(muk)=names(facteurech)=names(nb1)=NameBlocks
 
 
   if(Graph_weights==TRUE)
@@ -271,9 +321,9 @@ catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weig
   homogeneity=round(hom,3)*100
 
   #results
-  res=list(S=round(S,2),compromise=round(C,2),weights=round(u,2),lambda=round(lambda,2),overall_error=round(Q,2),
+  res=list(S=round(S,2),compromise=round(C,2),weights=round(u,5), weights_tests= Matrep, lambda=round(lambda,2),overall_error=round(Q,2),
            error_by_sub=round(dw,2), error_by_prod=round(obj,2), s_with_compromise=round(s,2), homogeneity=homogeneity, CA=e, eigenvalues=eigenvalues,
-           inertia=pouriner, scalefactors=round(facteurech,2), nb_1=muk**2, param=list(n=n, nblo=nblo, nvar=nvar))
+           inertia=pouriner, scalefactors=round(facteurech,2), nb_1=nb1, param=list(n=n, nblo=nblo, nvar=nvar))
   class(res)="catatis"
 
 
