@@ -31,7 +31,7 @@
 print.catatis=function(x, ...)
 {
   res.catatis=x
-  if(class(res.catatis)!="catatis")
+  if(inherits(res.catatis, "catatis")==FALSE)
   {
     stop("The class of the object must be 'catatis'")
   }
